@@ -1,3 +1,4 @@
+;;; -*- lexical-binding: t -*-
 (require 'yasnippet)
 
 ;; whitespace removing functions from Magnar Sveen ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -29,8 +30,9 @@
   (yas-s-trim comment-start))
 
 (defun yas-trimmed-comment-end ()
-  "This function returns `comment-end' trimmed by whitespaces if `comment-end' is not empty.
-Otherwise the reversed output of function `yas-trimmed-comment-start' is returned."
+  "This function returns `comment-end' trimmed by whitespaces if
+`comment-end' is not empty. Otherwise the reversed output of
+function `yas-trimmed-comment-start' is returned."
   (if (eq (length comment-end) 0)
       (yas-string-reverse (yas-trimmed-comment-start))
     (yas-s-trim comment-end)))
